Chicken Turtle Util (CTU) is a broad scoped Python utility library.

Links
=====
- `Documentation <http://chicken_turtle_util.readthedocs.io/en/4.1.1/>`_
- `PyPI <https://pypi.python.org/pypi/chicken_turtle_util/>`_
- `GitHub <https://github.com/timdiels/chicken_turtle_util/>`_

